@@ -3,19 +3,19 @@
 #
 vcov <- function(object, ...) UseMethod("vcov")
 
-vcov.nls <- function(object)
+vcov.nls <- function(object, ...)
 {
     sm <- summary(object)
     sm$cov.unscaled * sm$sigma^2
 }
 
-vcov.glm <- function(object)
+vcov.glm <- function(object, ...)
 {
     so <- summary(object, corr=FALSE)
     so$dispersion * so$cov.unscaled
 }
 
-vcov.lm <- function(object)
+vcov.lm <- function(object, ...)
 {
     so <- summary(object, corr=FALSE)
     so$sigma^2 * so$cov.unscaled
